The `Closure Compiler <http://code.google.com/closure/compiler/>`_ is
a tool for reducing the size of Javascript files to make them download
and run faster.

It's a Java-based tool. This package, in the spirit of the 
`yuicompressor <http://pypi.python.org/pypi/yuicompressor/>` package,
provides a simple way to install and use the the Closure compiler from 
Python, bundling the ``closure.jar`` with the Python package.

I recommend looking at `webassets`_ for your CSS/JS compression needs.

.. _webassets: https://github.com/miracle2k/webassets


--------
Versions
--------

Version ``YYYYMMDD`` of this package will bundle the corresponding 
version of the compiler (Closure uses the build date as the version).


If you want a new version to be uploaded, open a ticket at the
`Github page <https://github.com/miracle2k/python-closure>`_.
